@@ -23,7 +23,7 @@ import csv
 import enum
 import io
 import string
-from typing import Generic, List, Iterable, Optional, Sequence, Text, Type, TypeVar, Union
+from typing import Any, Dict, Generic, Iterable, List, Optional, Sequence, Type, TypeVar, Union
 from xml.dom import minidom
 
 from absl.flags import _helpers
@@ -33,16 +33,10 @@ _ET = TypeVar('_ET', bound=enum.Enum)
 _N = TypeVar('_N', int, float)
 
 
-def _is_integer_type(instance):
-  """Returns True if instance is an integer, and not a bool."""
-  return (isinstance(instance, int) and
-          not isinstance(instance, bool))
-
-
 class _ArgumentParserCache(type):
   """Metaclass used to cache and share argument parsers among flags."""
 
-  _instances = {}
+  _instances: Dict[Any, Any] = {}
 
   def __call__(cls, *args, **kwargs):
     """Returns an instance of the argument parser cls.
@@ -95,9 +89,9 @@ class ArgumentParser(Generic[_T], metaclass=_ArgumentParserCache):
   member variables must be derived from initializer arguments only.
   """
 
-  syntactic_help: Text = ''
+  syntactic_help: str = ''
 
-  def parse(self, argument: Text) -> Optional[_T]:
+  def parse(self, argument: str) -> Optional[_T]:
     """Parses the string argument and returns the native value.
 
     By default it returns its argument unmodified.
@@ -115,9 +109,9 @@ class ArgumentParser(Generic[_T], metaclass=_ArgumentParserCache):
     if not isinstance(argument, str):
       raise TypeError('flag value must be a string, found "{}"'.format(
           type(argument)))
-    return argument
+    return argument  # type: ignore[return-value]
 
-  def flag_type(self) -> Text:
+  def flag_type(self) -> str:
     """Returns a string representing the type of the flag."""
     return 'string'
 
@@ -136,7 +130,7 @@ class ArgumentParser(Generic[_T], metaclass=_ArgumentParserCache):
 class ArgumentSerializer(Generic[_T]):
   """Base class for generating string representations of a flag value."""
 
-  def serialize(self, value: _T) -> Text:
+  def serialize(self, value: _T) -> str:
     """Returns a serialized string of the value."""
     return str(value)
 
@@ -155,7 +149,7 @@ class NumericParser(ArgumentParser[_N]):
     return ((self.lower_bound is not None and val < self.lower_bound) or
             (self.upper_bound is not None and val > self.upper_bound))
 
-  def parse(self, argument: Text) -> _N:
+  def parse(self, argument: Union[str, _N]) -> _N:
     """See base class."""
     val = self.convert(argument)
     if self.is_outside_bounds(val):
@@ -174,7 +168,7 @@ class NumericParser(ArgumentParser[_N]):
           doc, 'upper_bound', self.upper_bound))
     return elements
 
-  def convert(self, argument: Text) -> _N:
+  def convert(self, argument: Union[str, _N]) -> _N:
     """Returns the correct numeric value of argument.
 
     Subclass must implement this method, and raise TypeError if argument is not
@@ -204,7 +198,7 @@ class FloatParser(NumericParser[float]):
       lower_bound: Optional[float] = None,
       upper_bound: Optional[float] = None,
   ) -> None:
-    super(FloatParser, self).__init__()
+    super().__init__()
     self.lower_bound = lower_bound
     self.upper_bound = upper_bound
     sh = self.syntactic_help
@@ -222,15 +216,18 @@ class FloatParser(NumericParser[float]):
 
   def convert(self, argument: Union[int, float, str]) -> float:
     """Returns the float value of argument."""
-    if (_is_integer_type(argument) or isinstance(argument, float) or
-        isinstance(argument, str)):
+    if (
+        (isinstance(argument, int) and not isinstance(argument, bool))
+        or isinstance(argument, float)
+        or isinstance(argument, str)
+    ):
       return float(argument)
     else:
       raise TypeError(
           'Expect argument to be a string, int, or float, found {}'.format(
               type(argument)))
 
-  def flag_type(self) -> Text:
+  def flag_type(self) -> str:
     """See base class."""
     return 'float'
 
@@ -247,7 +244,7 @@ class IntegerParser(NumericParser[int]):
   def __init__(
       self, lower_bound: Optional[int] = None, upper_bound: Optional[int] = None
   ) -> None:
-    super(IntegerParser, self).__init__()
+    super().__init__()
     self.lower_bound = lower_bound
     self.upper_bound = upper_bound
     sh = self.syntactic_help
@@ -267,9 +264,9 @@ class IntegerParser(NumericParser[int]):
       sh = '%s >= %s' % (self.number_name, lower_bound)
     self.syntactic_help = sh
 
-  def convert(self, argument: Union[int, Text]) -> int:
+  def convert(self, argument: Union[int, str]) -> int:
     """Returns the int value of argument."""
-    if _is_integer_type(argument):
+    if isinstance(argument, int) and not isinstance(argument, bool):
       return argument
     elif isinstance(argument, str):
       base = 10
@@ -283,7 +280,7 @@ class IntegerParser(NumericParser[int]):
       raise TypeError('Expect argument to be a string or int, found {}'.format(
           type(argument)))
 
-  def flag_type(self) -> Text:
+  def flag_type(self) -> str:
     """See base class."""
     return 'int'
 
@@ -291,7 +288,7 @@ class IntegerParser(NumericParser[int]):
 class BooleanParser(ArgumentParser[bool]):
   """Parser of boolean values."""
 
-  def parse(self, argument: Union[Text, int]) -> bool:
+  def parse(self, argument: Union[str, int]) -> bool:
     """See base class."""
     if isinstance(argument, str):
       if argument.lower() in ('true', 't', '1'):
@@ -311,16 +308,16 @@ class BooleanParser(ArgumentParser[bool]):
 
     raise TypeError('Non-boolean argument to boolean flag', argument)
 
-  def flag_type(self) -> Text:
+  def flag_type(self) -> str:
     """See base class."""
     return 'bool'
 
 
-class EnumParser(ArgumentParser[Text]):
+class EnumParser(ArgumentParser[str]):
   """Parser of a string enum value (a string value from a given set)."""
 
   def __init__(
-      self, enum_values: Iterable[Text], case_sensitive: bool = True
+      self, enum_values: Iterable[str], case_sensitive: bool = True
   ) -> None:
     """Initializes EnumParser.
 
@@ -332,17 +329,14 @@ class EnumParser(ArgumentParser[Text]):
       ValueError: When enum_values is empty.
     """
     if not enum_values:
-      raise ValueError(
-          'enum_values cannot be empty, found "{}"'.format(enum_values))
+      raise ValueError(f'enum_values cannot be empty, found "{enum_values}"')
     if isinstance(enum_values, str):
-      raise ValueError(
-          'enum_values cannot be a str, found "{}"'.format(enum_values)
-      )
-    super(EnumParser, self).__init__()
+      raise ValueError(f'enum_values cannot be a str, found "{enum_values}"')
+    super().__init__()
     self.enum_values = list(enum_values)
     self.case_sensitive = case_sensitive
 
-  def parse(self, argument: Text) -> Text:
+  def parse(self, argument: str) -> str:
     """Determines validity of argument and returns the correct element of enum.
 
     Args:
@@ -368,7 +362,7 @@ class EnumParser(ArgumentParser[Text]):
         return [value for value in self.enum_values
                 if value.upper() == argument.upper()][0]
 
-  def flag_type(self) -> Text:
+  def flag_type(self) -> str:
     """See base class."""
     return 'string enum'
 
@@ -391,7 +385,7 @@ class EnumClassParser(ArgumentParser[_ET]):
       ValueError: When enum_class is empty.
     """
     if not issubclass(enum_class, enum.Enum):
-      raise TypeError('{} is not a subclass of Enum.'.format(enum_class))
+      raise TypeError(f'{enum_class} is not a subclass of Enum.')
     if not enum_class.__members__:
       raise ValueError('enum_class cannot be empty, but "{}" is empty.'
                        .format(enum_class))
@@ -406,7 +400,7 @@ class EnumClassParser(ArgumentParser[_ET]):
             'Duplicate enum values for {} using case_sensitive=False'.format(
                 duplicate_keys))
 
-    super(EnumClassParser, self).__init__()
+    super().__init__()
     self.enum_class = enum_class
     self._case_sensitive = case_sensitive
     if case_sensitive:
@@ -416,11 +410,11 @@ class EnumClassParser(ArgumentParser[_ET]):
           name.lower() for name in enum_class.__members__)
 
   @property
-  def member_names(self) -> Sequence[Text]:
+  def member_names(self) -> Sequence[str]:
     """The accepted enum names, in lowercase if not case sensitive."""
     return self._member_names
 
-  def parse(self, argument: Union[_ET, Text]) -> _ET:
+  def parse(self, argument: Union[_ET, str]) -> _ET:
     """Determines validity of argument and returns the correct element of enum.
 
     Args:
@@ -448,17 +442,17 @@ class EnumClassParser(ArgumentParser[_ET]):
       return next(value for name, value in self.enum_class.__members__.items()
                   if name.lower() == key.lower())
 
-  def flag_type(self) -> Text:
+  def flag_type(self) -> str:
     """See base class."""
     return 'enum class'
 
 
 class ListSerializer(Generic[_T], ArgumentSerializer[List[_T]]):
 
-  def __init__(self, list_sep: Text) -> None:
+  def __init__(self, list_sep: str) -> None:
     self.list_sep = list_sep
 
-  def serialize(self, value: List[_T]) -> Text:
+  def serialize(self, value: List[_T]) -> str:
     """See base class."""
     return self.list_sep.join([str(x) for x in value])
 
@@ -470,7 +464,9 @@ class EnumClassListSerializer(ListSerializer[_ET]):
   provided separator.
   """
 
-  def __init__(self, list_sep: Text, **kwargs) -> None:
+  _element_serializer: 'EnumClassSerializer'
+
+  def __init__(self, list_sep: str, **kwargs) -> None:
     """Initializes EnumClassListSerializer.
 
     Args:
@@ -478,10 +474,10 @@ class EnumClassListSerializer(ListSerializer[_ET]):
       **kwargs: Keyword arguments to the `EnumClassSerializer` used to serialize
         individual values.
     """
-    super(EnumClassListSerializer, self).__init__(list_sep)
+    super().__init__(list_sep)
     self._element_serializer = EnumClassSerializer(**kwargs)
 
-  def serialize(self, value: Union[_ET, List[_ET]]) -> Text:
+  def serialize(self, value: Union[_ET, List[_ET]]) -> str:
     """See base class."""
     if isinstance(value, list):
       return self.list_sep.join(
@@ -490,9 +486,9 @@ class EnumClassListSerializer(ListSerializer[_ET]):
       return self._element_serializer.serialize(value)
 
 
-class CsvListSerializer(ListSerializer[Text]):
+class CsvListSerializer(ListSerializer[str]):
 
-  def serialize(self, value: List[Text]) -> Text:
+  def serialize(self, value: List[str]) -> str:
     """Serializes a list as a CSV string or unicode."""
     output = io.StringIO()
     writer = csv.writer(output, delimiter=self.list_sep)
@@ -515,7 +511,7 @@ class EnumClassSerializer(ArgumentSerializer[_ET]):
     """
     self._lowercase = lowercase
 
-  def serialize(self, value: _ET) -> Text:
+  def serialize(self, value: _ET) -> str:
     """Returns a serialized string of the Enum class value."""
     as_string = str(value.name)
     return as_string.lower() if self._lowercase else as_string
@@ -533,15 +529,15 @@ class BaseListParser(ArgumentParser):
   """
 
   def __init__(
-      self, token: Optional[Text] = None, name: Optional[Text] = None
+      self, token: Optional[str] = None, name: Optional[str] = None
   ) -> None:
     assert name
-    super(BaseListParser, self).__init__()
+    super().__init__()
     self._token = token
     self._name = name
     self.syntactic_help = 'a %s separated list' % self._name
 
-  def parse(self, argument: Text) -> List[Text]:
+  def parse(self, argument: str) -> List[str]:
     """See base class."""
     if isinstance(argument, list):
       return argument
@@ -550,7 +546,7 @@ class BaseListParser(ArgumentParser):
     else:
       return [s.strip() for s in argument.split(self._token)]
 
-  def flag_type(self) -> Text:
+  def flag_type(self) -> str:
     """See base class."""
     return '%s separated list of strings' % self._name
 
@@ -559,9 +555,9 @@ class ListParser(BaseListParser):
   """Parser for a comma-separated list of strings."""
 
   def __init__(self) -> None:
-    super(ListParser, self).__init__(',', 'comma')
+    super().__init__(',', 'comma')
 
-  def parse(self, argument: Union[Text, List[Text]]) -> List[Text]:
+  def parse(self, argument: Union[str, List[str]]) -> List[str]:
     """Parses argument as comma-separated list of strings."""
     if isinstance(argument, list):
       return argument
@@ -582,7 +578,7 @@ class ListParser(BaseListParser):
   def _custom_xml_dom_elements(
       self, doc: minidom.Document
   ) -> List[minidom.Element]:
-    elements = super(ListParser, self)._custom_xml_dom_elements(doc)
+    elements = super()._custom_xml_dom_elements(doc)
     elements.append(_helpers.create_xml_dom_element(
         doc, 'list_separator', repr(',')))
     return elements
@@ -601,9 +597,9 @@ class WhitespaceSeparatedListParser(BaseListParser):
     """
     self._comma_compat = comma_compat
     name = 'whitespace or comma' if self._comma_compat else 'whitespace'
-    super(WhitespaceSeparatedListParser, self).__init__(None, name)
+    super().__init__(None, name)
 
-  def parse(self, argument: Union[Text, List[Text]]) -> List[Text]:
+  def parse(self, argument: Union[str, List[str]]) -> List[str]:
     """Parses argument as whitespace-separated list of strings.
 
     It also parses argument as comma-separated list of strings if requested.
@@ -626,8 +622,7 @@ class WhitespaceSeparatedListParser(BaseListParser):
   def _custom_xml_dom_elements(
       self, doc: minidom.Document
   ) -> List[minidom.Element]:
-    elements = super(WhitespaceSeparatedListParser, self
-                    )._custom_xml_dom_elements(doc)
+    elements = super()._custom_xml_dom_elements(doc)
     separators = list(string.whitespace)
     if self._comma_compat:
       separators.append(',')
